package com.example.prm02

import android.content.ContentValues
import com.example.prm02.DbContract.DebtorEntry

object DataManager {

    fun fetchAllDebtors(dbHelper: DbHelper) : ArrayList<Debtor> {

        val debtors = ArrayList<Debtor>()

        val db = dbHelper.readableDatabase

        val columns = arrayOf(
            DebtorEntry.COLUMN_ID,
            DebtorEntry.COLUMN_NAME,
            DebtorEntry.COLUMN_DEBT
        )

        val cursor = db.query(
            DebtorEntry.TABLE_NAME,
            columns,
            null,
            null,
            null,
            null,
            null)

        val idPos = cursor.getColumnIndex(DebtorEntry.COLUMN_ID)
        val namePos = cursor.getColumnIndex(DebtorEntry.COLUMN_NAME)
        val debtPos = cursor.getColumnIndex(DebtorEntry.COLUMN_DEBT)

        while (cursor.moveToNext()) {
            val id = cursor.getString(idPos).toInt()
            val name = cursor.getString(namePos)
            val debt = cursor.getString(debtPos)
            debtors.add(Debtor(id, name, debt))
        }

        cursor.close()
        return debtors
    }

    fun fetchDebtor(dbHelper: DbHelper, debtorId: Int) : Debtor? {
        val db = dbHelper.readableDatabase
        var debtor: Debtor? = null
        val columns = arrayOf(
            DebtorEntry.COLUMN_NAME,
            DebtorEntry.COLUMN_DEBT
        )
        val selection = DebtorEntry.COLUMN_ID + " LIKE ? "
        val selectionArgs = arrayOf(debtorId.toString() )
        val cursor = db.query(
            DebtorEntry.TABLE_NAME,
            columns,
            selection,
            selectionArgs,
            null,
            null,
            null)
        val namePos = cursor.getColumnIndex(DebtorEntry.COLUMN_NAME)
        val debtPos = cursor.getColumnIndex(DebtorEntry.COLUMN_DEBT)

        while (cursor.moveToNext()) {
            val name = cursor.getString(namePos)
            val debt = cursor.getString(debtPos)
            debtor = Debtor(debtorId.toInt() , name, debt)
        }
        cursor.close()
        return debtor
    }

    fun updateDebtor(dbHelper: DbHelper, debtor: Debtor){
        val db = dbHelper.writableDatabase
        val values = ContentValues()

        values.put(DebtorEntry.COLUMN_NAME, debtor.name)
        values.put(DebtorEntry.COLUMN_DEBT, debtor.debt)

        val selection = DebtorEntry.COLUMN_ID + " LIKE ? "
        val selectionArgs = arrayOf(debtor.id.toString() )

        db.update(DebtorEntry.TABLE_NAME, values, selection, selectionArgs)
    }

    fun deleteDebtor(dbHelper: DbHelper, debtorId: Int) : Int? {
        val db = dbHelper.writableDatabase
        val selection = DebtorEntry.COLUMN_ID + " LIKE ? "
        val selectionArgs = arrayOf(debtorId.toString() )

        return db.delete(DebtorEntry.TABLE_NAME, selection, selectionArgs)
    }
}